@@ -6,6 +6,6 @@
 #' @export
 kde.2D <- function(...) {
      .Deprecated("mwCorr", package="spatialEco", 
-	 msg="kde2D is deprecated, please use sp.kde which provides a weghted option")
+	 msg="kde2D is deprecated, please use sp.kde which provides a weighted option")
   kde.2D(...)
 }
